const sleep = require("sleep-promise");
const BDKAgentClient = require("../EndpointClients/BDKAgent");
const AFCMakeCallEndpointBase = require("./AFCMakeCallEndpointBase");
const powerSingleton = require("../Modules").PowerSingleton;

module.exports =
	class BDKAgent extends AFCMakeCallEndpointBase
	{
		constructor()
		{
			super(
				/*strName*/ "BDKAgent",
				/*strPath*/ "/api-ws/BDKAgent",
				/*objReflection*/ {},
				/*classReverseCallsClient*/ BDKAgentClient
			);

			this._objAFCPromises = {};
			this._bUpdatePrerequisiteFinished = false;
		}

		/**
		 * @param {JSONRPC.IncomingRequest} incomingRequest
		 * @param {boolean} bForce = false
		 * @param {number} nTimeoutMilliseconds = 0
		 * @returns {string}
		 */
		async bdk_agent_reboot(incomingRequest, bForce, nTimeoutMilliseconds)
		{
			await powerSingleton.powerOff(/*bReboot*/ true, bForce, nTimeoutMilliseconds);

			return "Server will now reboot.";
		}

		/**
		 * @param {JSONRPC.IncomingRequest} incomingRequest
		 * @param {boolean} bForce = false
		 * @param {number} nTimeoutMilliseconds = 0
		 * @returns {string}
		 */
		async bdk_agent_shutdown(incomingRequest, bForce, nTimeoutMilliseconds)
		{
			await powerSingleton.powerOff(/*bReboot*/ false, bForce, nTimeoutMilliseconds);

			return "Server will now shutdown.";
		}

		/**
		 * @param {JSONRPC.IncomingRequest} incomingRequest
		 * @param {number} nSleepSeconds
		 * @returns {string}
		 */
		async bdk_agent_test(incomingRequest, nSleepSeconds)
		{
			const strStartTime = new Date().toISOString();
			await sleep(nSleepSeconds * 1000);

			return "Hello! Test start time: " + strStartTime + ". End time: " + (new Date().toISOString());
		}

		/**
		 * Exits the current process after 2 seconds using setTimeout().
		 * Should return before the setTimeout's callback executes. Two seconds should be enough time to return.
		 *
		 * @param {JSONRPC.IncomingRequest} incomingRequest
		 * 
		 * @returns {string} 
		 */
		async bdk_agent_process_exit(incomingRequest)
		{
			setTimeout(
				() =>
				{
					try
					{
						console.log("Will process.exit(1) now.");
						process.exit(1);
					}
					catch (error)
					{
						console.error(error);
					}
				},
				2000
			);
			
			return "Will process.exit(1) in 2 seconds"
		}
	};
